@@ -6,7 +6,8 @@ import requests
 
 from ..classes.programme import Programme
 from ..const import RESPONSE_OK
-from .const_gb import CHANNEL_IMAGE_URL, LIVE_IMAGE_URL, PVR_IMAGE_URL, SCHEDULE_URL
+from .const_gb import (CHANNEL_IMAGE_URL, LIVE_IMAGE_URL, PVR_IMAGE_URL,
+                       SCHEDULE_URL)
 
 _LOGGER = logging.getLogger(__name__)
 
